==> nextcloud-22.2.3p0.tgz: nextcloud/apps/serverinfo/l10n/fa.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "اطلاعات CPU در دسترس نیست",
    "Load average" : "متوسط بار",
    "Last minute" : "آخرین لحظه",
    "Memory info not available" : "اطلاعات حافظه در دسترس نیست",
    "Total" : "جمع",
    "Current usage" : "مصرف کنونی",
    "Users" : "کاربران",
    "Groups" : "گروه ها",
    "Links" : "پیوندها",
    "Mails" : "نامه",
    "Federated sent" : "فدرال ارسال شده است",
    "Federated received" : "فدرال دریافت شده است",
    "Talk conversations" : "مکالمات صحبت کنید",
    "24 hours" : "24 ساعت",
    "1 hour" : "1 ساعت",
    "5 mins" : "5 دقیقه",
    "Copy" : "کپی کردن",
    "Copied!" : "کپی شده",
    "Not supported!" : "پشتیبانی وجود ندارد!",
    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
    "System" : "سیستم",
    "Monitoring" : "نظارت بر",
    "Monitoring app with useful server information" : "برنامه نظارت با اطلاعات سرور مفید",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "اطلاعات سرور مفیدی مانند بار CPU ، استفاده از رم ، استفاده دیسک ، تعداد کاربران و غیره را ارائه می دهد.",
    "Operating System" : "سیستم عامل",
    "CPU" : "پردازنده",
    "Memory" : "حافظه",
    "Server time" : "زمان سرور",
    "Uptime" : "وقت تمام وقت",
    "Load" : "بار",
    "Disk" : "دیسک",
    "Mount" : "کوه",
    "Filesystem" : "سیستم فایل",
    "Size" : "اندازه",
    "Available" : "در دسترس",
    "Used" : "استفاده شده",
    "You will get a notification once one of your disks is nearly full." : "هنگامی که یکی از دیسک های شما تقریباً کامل شد ، یک اعلان دریافت خواهید کرد.",
    "Files:" : "فایل ها:",
    "Storages:" : "انبارها:",
    "Free Space:" : "فضای خالی:",
    "Network" : "شبکه",
    "Hostname" : "نام میزبان",
    "DNS" : "DNS",
    "Gateway" : "دروازه",
    "Status" : "وضعیت",
    "Speed" : "سرعت",
    "MAC" : "مک",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "کاربران فعال",
    "Total users:" : "تعداد کل کاربران:",
    "Shares" : "اشتراک گذاری ها",
    "PHP" : "PHP",
    "Version:" : "نسخه:",
    "Memory Limit:" : "حد حافظه:",
    "Max Execution Time:" : "حداکثر زمان اجرا:",
    "Upload max size:" : "اندازه حداکثر بارگذاری شود:",
    "Database" : "پایگاه داده",
    "Type:" : "نوع:",
    "Size:" : "اندازه",
    "External monitoring tool" : "ابزار نظارت خارجی",
    "You can connect an external monitoring tool by using this end point:" : "با استفاده از این نقطه پایانی می توانید یک ابزار نظارت خارجی را به هم متصل شدن:",
    "Time Servers" : "زمان سرور"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/serverinfo/l10n/fa.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "اطلاعات CPU در دسترس نیست",
    "Users" : "کاربران",
    "Groups" : "گروه ها",
    "Links" : "پیوندها",
    "Emails" : "ایمیل",
    "Federated sent" : "فدرال ارسال شده است",
    "Federated received" : "فدرال دریافت شده است",
    "Talk conversations" : "مکالمات صحبت کنید",
    "24 hours" : "24 ساعت",
    "1 hour" : "1 ساعت",
    "5 mins" : "5 دقیقه",
    "Copy" : "کپی کردن",
    "Copied!" : "کپی شده",
    "Not supported!" : "پشتیبانی وجود ندارد!",
    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
    "System" : "سیستم",
    "Monitoring" : "نظارت بر",
    "Monitoring app with useful server information" : "برنامه نظارت با اطلاعات سرور مفید",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "اطلاعات سرور مفیدی مانند بار CPU ، استفاده از رم ، استفاده دیسک ، تعداد کاربران و غیره را ارائه می دهد.",
    "Load" : "بار",
    "Memory" : "حافظه",
    "Disk" : "دیسک",
    "Size:" : "اندازه",
    "You will get a notification once one of your disks is nearly full." : "هنگامی که یکی از دیسک های شما تقریباً کامل شد ، یک اعلان دریافت خواهید کرد.",
    "Files:" : "فایل ها:",
    "Storages:" : "انبارها:",
    "Free Space:" : "فضای خالی:",
    "Network" : "شبکه",
    "Active users" : "کاربران فعال",
    "Total users:" : "تعداد کل کاربران:",
    "Shares" : "اشتراک گذاری ها",
    "PHP" : "PHP",
    "Version:" : "نسخه:",
    "Upload max size:" : "اندازه حداکثر بارگذاری شود:",
    "Database" : "پایگاه داده",
    "Type:" : "نوع:",
    "External monitoring tool" : "ابزار نظارت خارجی",
    "You can connect an external monitoring tool by using this end point:" : "با استفاده از این نقطه پایانی می توانید یک ابزار نظارت خارجی را به هم متصل شدن:",
    "Load average" : "متوسط بار",
    "Last minute" : "آخرین لحظه",
    "Memory info not available" : "اطلاعات حافظه در دسترس نیست",
    "Total" : "جمع",
    "Current usage" : "مصرف کنونی",
    "Mails" : "نامه",
    "Operating System" : "سیستم عامل",
    "CPU" : "پردازنده",
    "Server time" : "زمان سرور",
    "Uptime" : "وقت تمام وقت",
    "Mount" : "کوه",
    "Filesystem" : "سیستم فایل",
    "Size" : "اندازه",
    "Available" : "در دسترس",
    "Used" : "استفاده شده",
    "Hostname" : "نام میزبان",
    "DNS" : "DNS",
    "Gateway" : "دروازه",
    "Status" : "وضعیت",
    "Speed" : "سرعت",
    "MAC" : "مک",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Memory Limit:" : "حد حافظه:",
    "Max Execution Time:" : "حداکثر زمان اجرا:",
    "Files" : "فایل ها",
    "Version" : "نسخه",
    "Type" : "نوع"
},
"nplurals=2; plural=(n > 1);");
